@@ -47,11 +47,11 @@ token_verifier = Auth0TokenVerifier()
 
 token_cache_redis = None # TODO rework the global clients.
 
-def get_wallet(token: str, token_verifier: object):
+def get_uid(token: str, token_verifier: object):
     log = logging.getLogger(__name__)
     global token_cache_redis
     if settings.redis_host:
-        if not token_cache_redis:
+        if token_cache_redis is None:
             token_cache_redis = redis.Redis(
                 settings.redis_host, settings.redis_port,
                 db=settings.token_cache_db_id,
@@ -59,14 +59,17 @@ def get_wallet(token: str, token_verifier: object):
                 )
         cached_value = token_cache_redis.get(token.credentials)
         if cached_value is not None:
-            return cached_value
+            return cached_value.decode('utf-8')
     try:
+        log.warn('credentials %s', token.credentials)
         result = token_verifier.verify(token.credentials)
+        log.warn('result %s', result)
         if result.get("status") == 'error':
             raise IllegalTokenExcpetion()
-        value = result.get(f"{settings.auth0_namespace}wallet")
-        if token_cache_redis:
-            ttl = 86400 * 1000 # hard code
+        value = result.get(f"{settings.auth0_namespace}uid")
+        log.warn('uid retrieved is %s', value)
+        if token_cache_redis is not None and value:
+            ttl = 86400 * 1000 # hard code 1 day, ttl value is in milliseconds
             token_cache_redis.setex(token.credentials, ttl, value)
         return value
     except Exception as e:
@@ -99,8 +102,8 @@ def create_app():
         """
         Find this user's own profile info.
         """
-        wallet = get_wallet(token, token_verifier)
-        return es_get_result_to_dict(es.get(index=settings.es_index, id=f"{wallet}:{settings.app_type}"))
+        uid = get_uid(token, token_verifier)
+        return es_get_result_to_dict(es.get(index=settings.es_index, id=f"{uid}:{settings.app_type}"))
 
     @app.patch("/me")
     def update_own_profile_info(profile: ConsumerProfile, token: str = Depends(token_auth_scheme)):
@@ -109,8 +112,8 @@ def create_app():
         If the profile does not exist, create it in the first place.
         """
         profile = jsonable_encoder(profile)
-        wallet = get_wallet(token, token_verifier)
-        return es.update(index=settings.es_index, id=f"{wallet}:{settings.app_type}", doc_as_upsert=True, doc=profile)
+        uid = get_uid(token, token_verifier)
+        return es.update(index=settings.es_index, id=f"{uid}:{settings.app_type}", doc_as_upsert=True, doc=profile)
     @app.get('/config/app')
     def get_app_config():
         """get application default configuration"""
