@@ -8,14 +8,14 @@ def es_get_result_to_dict(es_result: dict) -> dict:
     A typical es result
     {
     "_index": "local-bdating",
-    "_id": "0x7bf572eF922A79d5e01d064506f682caaCa0abCd:provider",
+    "_id": "a0abCd:provider",
     "_version": 1,
     "_seq_no": 0,
     "_primary_term": 1,
     "found": true,
     "_source": {
       "type": "provider",
-      "wallet": "0x7bf572eF922A79d5e01d064506f682caaCa0abCd",
+      "uid":"23fdad",
       "address": "10809 Mercedes Loaf Apt. 552\nNancyborough, ID 01277",
       "location": [
         -38.1355732927354,
@@ -50,11 +50,12 @@ def es_search_result_to_dict(es_result: dict) -> dict:
     "hits" : [
       {
         "_index" : "local-bdating",
-        "_id" : "0x7bf572eF922A79d5e01d064506f682caaCa0abCd:slot",
+        "_id" : "a0abCd:slot",
         "_score" : 0.020639554,
         "_source" : {
           "type" : "slot",
-          "wallet" : "0x7bf572eF922A79d5e01d064506f682caaCa0abCd",
+          "uid" : "a0abCd",
+          
           "address" : """Unit 9190 Box 6681
 
 
@@ -102,45 +103,3 @@ def validate_slot_id(slot_id: int):
     if slot_id / 1000000 < 2020 or slot_id / 1000000 > 4000:
         raise HTTPException(
             status_code=400, detail="slot id year part must be resonable")
-
-
-# def limit_query_condition(query_condition=None):
-#     if query_condition:
-#         return {
-#             "query": {
-#                 "bool": {
-#                     "must": [
-#                         {
-#                             "match": {
-#                                 "wallet": TODO_DELETE_ME
-#                             }
-#                         },
-#                         {
-#                             "match": {
-#                                 "type": TYPE
-#                             }
-#                         },
-#                         query_condition
-#                     ]
-#                 }
-#             }
-#         }
-#     else:
-#         return {
-#             "query": {
-#                 "bool": {
-#                     "must": [
-#                         {
-#                             "match": {
-#                                 "wallet": TODO_DELETE_ME
-#                             }
-#                         },
-#                         {
-#                             "match": {
-#                                 "type": TYPE
-#                             }
-#                         },
-#                     ]
-#                 }
-#             }
-#         }
