@@ -12,9 +12,11 @@ class Location(BaseModel):
 
 class BaseProfile(BaseModel):
   wallet: Optional[str]
+  uid: Optional[str]
   name: str
   referrer: str = None
   gender: str = None
+  register_timestamp: int = 0
 
 
 class EyeColor(str, Enum):
@@ -36,6 +38,7 @@ class HairColor(str, Enum):
 class Ethnicity(str, Enum):
   asian = 'asian'
   caucasian = 'caucasian'
+  australian = 'australian'
 
 
 class BuildType(str, Enum):
@@ -72,6 +75,13 @@ class DressSize(str, Enum):
   small_minus = 'small-'
 
 
+class SpeakingLanguage (str, Enum):
+  english = 'english'
+  chinese = 'chinese'
+  japanese = 'japanese'
+  korea = 'korean'
+
+
 class ProviderProfile(BaseProfile):
   address: str
   age: int = 27
@@ -88,6 +98,7 @@ class ProviderProfile(BaseProfile):
   bust: Optional[BustSize]
   rating: Optional[float]
   dress_size: Optional[DressSize]
+  speaking_language: List[SpeakingLanguage] = []
 
 
 class ConsumerProfile(BaseProfile):
@@ -105,7 +116,8 @@ class TimeSlot(ProviderProfile):
   slot_status: TimeSlotStatus = TimeSlotStatus.available
 
 
-class BookingDetail(TimeSlot):  # details of a booking, which is shown to the provider and consumer
+# details of a booking, which is shown to the provider and consumer
+class BookingDetail(TimeSlot):
   total_fee_aud: int
 
 
@@ -126,8 +138,8 @@ class BookingStatus(str, Enum):
 
 
 class Booking(BaseModel):  # booking to a timeslot
-  consumer_wallet: str
-  provider_wallet: str
+  consumer_uid: str
+  provider_uid: str
   all_slots: List[int] = []
   status: BookingStatus
   consumer_comments: Optional[str]
@@ -136,14 +148,14 @@ class Booking(BaseModel):  # booking to a timeslot
   provider_rating: Optional[float]
   last_update: int
   detail: BookingDetail
-  price: int
+  total_fee_aud: int
   book_time: int  # epoch second of booked
   history: List[BookingHistory] = []
 
 
 class Transaction(BaseModel):
-  consumer_wallet: str
-  provider_wallet: str
+  consumer_uid: str
+  provider_uid: str
   booking: Booking
   timestamp: int
   total_fee_aud: int
@@ -204,4 +216,3 @@ class OrderListResponse(BaseProfile):
 
 class HealthResponse(BaseModel):
   status: str
-
